@@ -733,7 +733,7 @@
     }
 
     # null model support
-    X <- if (!is.empty.model(mt)) model.matrix(mt, mf, contrasts)
+    X <- if (!is.empty.model(mt)) model.matrix(mt, mf)
     X <- as.matrix(X)         # X matrix
     xvars <- dimnames(X)[[2]] # X variable names
     xobs  <- dimnames(X)[[1]] # X observation names
